// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KIRIGAMIAPP_VERSION_H
#define KIRIGAMIAPP_VERSION_H

#define KIRIGAMIAPP_VERSION_STRING "1.12.1"
#define KIRIGAMIAPP_VERSION_MAJOR 1
#define KIRIGAMIAPP_VERSION_MINOR 12
#define KIRIGAMIAPP_VERSION_PATCH 1
#define KIRIGAMIAPP_VERSION ((1<<16)|(12<<8)|(1))

#endif
