
#ifndef KIRIGAMIAPP_EXPORT_H
#define KIRIGAMIAPP_EXPORT_H

#ifdef KIRIGAMIAPP_STATIC_DEFINE
#  define KIRIGAMIAPP_EXPORT
#  define KIRIGAMIAPP_NO_EXPORT
#else
#  ifndef KIRIGAMIAPP_EXPORT
#    ifdef KirigamiApp_EXPORTS
        /* We are building this library */
#      define KIRIGAMIAPP_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KIRIGAMIAPP_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KIRIGAMIAPP_NO_EXPORT
#    define KIRIGAMIAPP_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KIRIGAMIAPP_DECL_DEPRECATED
#  define KIRIGAMIAPP_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KIRIGAMIAPP_DECL_DEPRECATED_EXPORT
#  define KIRIGAMIAPP_DECL_DEPRECATED_EXPORT KIRIGAMIAPP_EXPORT KIRIGAMIAPP_DECL_DEPRECATED
#endif

#ifndef KIRIGAMIAPP_DECL_DEPRECATED_NO_EXPORT
#  define KIRIGAMIAPP_DECL_DEPRECATED_NO_EXPORT KIRIGAMIAPP_NO_EXPORT KIRIGAMIAPP_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KIRIGAMIAPP_NO_DEPRECATED
#    define KIRIGAMIAPP_NO_DEPRECATED
#  endif
#endif
#include <kirigamiapp_version.h>

#define KIRIGAMIAPP_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(KIRIGAMIAPP_NO_DEPRECATED)
#  undef KIRIGAMIAPP_DEPRECATED
#  define KIRIGAMIAPP_DEPRECATED_EXPORT KIRIGAMIAPP_EXPORT
#  define KIRIGAMIAPP_DEPRECATED_NO_EXPORT KIRIGAMIAPP_NO_EXPORT
#elif defined(KIRIGAMIAPP_NO_DEPRECATED_WARNINGS)
#  define KIRIGAMIAPP_DEPRECATED
#  define KIRIGAMIAPP_DEPRECATED_EXPORT KIRIGAMIAPP_EXPORT
#  define KIRIGAMIAPP_DEPRECATED_NO_EXPORT KIRIGAMIAPP_NO_EXPORT
#else
#  define KIRIGAMIAPP_DEPRECATED KIRIGAMIAPP_DECL_DEPRECATED
#  define KIRIGAMIAPP_DEPRECATED_EXPORT KIRIGAMIAPP_DECL_DEPRECATED_EXPORT
#  define KIRIGAMIAPP_DEPRECATED_NO_EXPORT KIRIGAMIAPP_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KIRIGAMIAPP_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KIRIGAMIAPP_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KIRIGAMIAPP_NO_DEPRECATED
#  define KIRIGAMIAPP_DISABLE_DEPRECATED_BEFORE_AND_AT KIRIGAMIAPP_VERSION
#endif
#ifdef KIRIGAMIAPP_NO_DEPRECATED_WARNINGS
#  define KIRIGAMIAPP_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KIRIGAMIAPP_DEPRECATED_WARNINGS_SINCE
#  ifdef KIRIGAMIAPP_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KIRIGAMIAPP_DEPRECATED_WARNINGS_SINCE KIRIGAMIAPP_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KIRIGAMIAPP_DEPRECATED_WARNINGS_SINCE KIRIGAMIAPP_VERSION
#  endif
#endif

#ifndef KIRIGAMIAPP_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KIRIGAMIAPP_DISABLE_DEPRECATED_BEFORE_AND_AT 0x10000
#endif

#ifdef KIRIGAMIAPP_DEPRECATED
#  define KIRIGAMIAPP_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KIRIGAMIAPP_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KIRIGAMIAPP_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KIRIGAMIAPP_EXPORT_H */
