// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KIRIGAMIADDONSCOMPONENTS_VERSION_H
#define KIRIGAMIADDONSCOMPONENTS_VERSION_H

#define KIRIGAMIADDONSCOMPONENTS_VERSION_STRING "1.12.1"
#define KIRIGAMIADDONSCOMPONENTS_VERSION_MAJOR 1
#define KIRIGAMIADDONSCOMPONENTS_VERSION_MINOR 12
#define KIRIGAMIADDONSCOMPONENTS_VERSION_PATCH 1
#define KIRIGAMIADDONSCOMPONENTS_VERSION ((1<<16)|(12<<8)|(1))

#endif
