
#ifndef KIRIGAMIADDONSCOMPONENTS_EXPORT_H
#define KIRIGAMIADDONSCOMPONENTS_EXPORT_H

#ifdef KIRIGAMIADDONSCOMPONENTS_STATIC_DEFINE
#  define KIRIGAMIADDONSCOMPONENTS_EXPORT
#  define KIRIGAMIADDONSCOMPONENTS_NO_EXPORT
#else
#  ifndef KIRIGAMIADDONSCOMPONENTS_EXPORT
#    ifdef KirigamiAddonsComponents_EXPORTS
        /* We are building this library */
#      define KIRIGAMIADDONSCOMPONENTS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KIRIGAMIADDONSCOMPONENTS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KIRIGAMIADDONSCOMPONENTS_NO_EXPORT
#    define KIRIGAMIADDONSCOMPONENTS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KIRIGAMIADDONSCOMPONENTS_DECL_DEPRECATED
#  define KIRIGAMIADDONSCOMPONENTS_DECL_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KIRIGAMIADDONSCOMPONENTS_DECL_DEPRECATED_EXPORT
#  define KIRIGAMIADDONSCOMPONENTS_DECL_DEPRECATED_EXPORT KIRIGAMIADDONSCOMPONENTS_EXPORT KIRIGAMIADDONSCOMPONENTS_DECL_DEPRECATED
#endif

#ifndef KIRIGAMIADDONSCOMPONENTS_DECL_DEPRECATED_NO_EXPORT
#  define KIRIGAMIADDONSCOMPONENTS_DECL_DEPRECATED_NO_EXPORT KIRIGAMIADDONSCOMPONENTS_NO_EXPORT KIRIGAMIADDONSCOMPONENTS_DECL_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KIRIGAMIADDONSCOMPONENTS_NO_DEPRECATED
#    define KIRIGAMIADDONSCOMPONENTS_NO_DEPRECATED
#  endif
#endif
#include <kirigamiaddonscomponents_version.h>

#define KIRIGAMIADDONSCOMPONENTS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

#if defined(KIRIGAMIADDONSCOMPONENTS_NO_DEPRECATED)
#  undef KIRIGAMIADDONSCOMPONENTS_DEPRECATED
#  define KIRIGAMIADDONSCOMPONENTS_DEPRECATED_EXPORT KIRIGAMIADDONSCOMPONENTS_EXPORT
#  define KIRIGAMIADDONSCOMPONENTS_DEPRECATED_NO_EXPORT KIRIGAMIADDONSCOMPONENTS_NO_EXPORT
#elif defined(KIRIGAMIADDONSCOMPONENTS_NO_DEPRECATED_WARNINGS)
#  define KIRIGAMIADDONSCOMPONENTS_DEPRECATED
#  define KIRIGAMIADDONSCOMPONENTS_DEPRECATED_EXPORT KIRIGAMIADDONSCOMPONENTS_EXPORT
#  define KIRIGAMIADDONSCOMPONENTS_DEPRECATED_NO_EXPORT KIRIGAMIADDONSCOMPONENTS_NO_EXPORT
#else
#  define KIRIGAMIADDONSCOMPONENTS_DEPRECATED KIRIGAMIADDONSCOMPONENTS_DECL_DEPRECATED
#  define KIRIGAMIADDONSCOMPONENTS_DEPRECATED_EXPORT KIRIGAMIADDONSCOMPONENTS_DECL_DEPRECATED_EXPORT
#  define KIRIGAMIADDONSCOMPONENTS_DEPRECATED_NO_EXPORT KIRIGAMIADDONSCOMPONENTS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KIRIGAMIADDONSCOMPONENTS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KIRIGAMIADDONSCOMPONENTS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KIRIGAMIADDONSCOMPONENTS_NO_DEPRECATED
#  define KIRIGAMIADDONSCOMPONENTS_DISABLE_DEPRECATED_BEFORE_AND_AT KIRIGAMIADDONSCOMPONENTS_VERSION
#endif
#ifdef KIRIGAMIADDONSCOMPONENTS_NO_DEPRECATED_WARNINGS
#  define KIRIGAMIADDONSCOMPONENTS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KIRIGAMIADDONSCOMPONENTS_DEPRECATED_WARNINGS_SINCE
#  ifdef KIRIGAMIADDONSCOMPONENTS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KIRIGAMIADDONSCOMPONENTS_DEPRECATED_WARNINGS_SINCE KIRIGAMIADDONSCOMPONENTS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KIRIGAMIADDONSCOMPONENTS_DEPRECATED_WARNINGS_SINCE KIRIGAMIADDONSCOMPONENTS_VERSION
#  endif
#endif

#ifndef KIRIGAMIADDONSCOMPONENTS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KIRIGAMIADDONSCOMPONENTS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x10000
#endif

#ifdef KIRIGAMIADDONSCOMPONENTS_DEPRECATED
#  define KIRIGAMIADDONSCOMPONENTS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KIRIGAMIADDONSCOMPONENTS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KIRIGAMIADDONSCOMPONENTS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#endif /* KIRIGAMIADDONSCOMPONENTS_EXPORT_H */
